
From: dmitry pervushin <dpervushin@ru.mvista.com>

This patch is to provide support for cs89x0-based network device on
Philips' pnx0105 board.

Signed-off-by: dmitry pervushin <dpervushin@ru.mvista.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 drivers/net/Kconfig  |    2 +-
 drivers/net/cs89x0.c |   39 ++++++++++++++++++++++++++++++++++++---
 drivers/net/cs89x0.h |    2 +-
 3 files changed, 38 insertions(+), 5 deletions(-)

diff -puN drivers/net/cs89x0.c~cs89x0c-support-for-philips-pnx0105-network-adapter drivers/net/cs89x0.c
--- 25/drivers/net/cs89x0.c~cs89x0c-support-for-philips-pnx0105-network-adapter	2005-05-23 19:41:00.000000000 -0700
+++ 25-akpm/drivers/net/cs89x0.c	2005-05-23 19:41:00.000000000 -0700
@@ -174,6 +174,13 @@ static unsigned int cs8900_irq_map[] = {
 #include <asm/irq.h>
 static unsigned int netcard_portlist[] __initdata = {IXDP2X01_CS8900_VIRT_BASE, 0};
 static unsigned int cs8900_irq_map[] = {IRQ_IXDP2X01_CS8900, 0, 0, 0};
+#elif defined(CONFIG_ARCH_PNX0105)
+#include <asm/irq.h>
+#include <asm/arch/gpio.h>
+#define CIRRUS_DEFAULT_BASE	IO_ADDRESS(EXT_STATIC2_s0_BASE + 0x200000)	/* = Physical address 0x48200000 */
+#define CIRRUS_DEFAULT_IRQ	VH_INTC_INT_NUM_CASCADED_INTERRUPT_1 /* Event inputs bank 1 - ID 35/bit 3 */
+static unsigned int netcard_portlist[] __initdata = {CIRRUS_DEFAULT_BASE, 0};
+static unsigned int cs8900_irq_map[] = {CIRRUS_DEFAULT_IRQ, 0, 0, 0};
 #else
 static unsigned int netcard_portlist[] __initdata =
    { 0x300, 0x320, 0x340, 0x360, 0x200, 0x220, 0x240, 0x260, 0x280, 0x2a0, 0x2c0, 0x2e0, 0};
@@ -431,6 +438,29 @@ cs89x0_probe1(struct net_device *dev, in
 #endif
         }
 
+#ifdef CONFIG_ARCH_PNX0105
+	initialize_ebi() ;
+
+	/* Map GPIO registers for the pins connected to the CS8900a. */
+	if ( map_cirrus_gpio() < 0 )
+		return (-ENODEV) ;
+
+	reset_cirrus();
+
+	/* Map event-router registers. */
+	if ( map_event_router() < 0 )
+		return (-ENODEV) ;
+
+	enable_cirrus_irq();
+
+	unmap_cirrus_gpio();
+	unmap_event_router();
+
+	dev->base_addr = ioaddr;
+
+	for ( i=0 ; i<3 ; i++ ) readreg( dev, 0 ) ;
+#endif
+
 	/* Grab the region so we can find another board if autoIRQ fails. */
 	/* WTF is going on here? */
 	if (!request_region(ioaddr & ~3, NETCARD_IO_EXTENT, DRV_NAME)) {
@@ -672,7 +702,7 @@ printk("PP_addr=0x%x\n", inw(ioaddr + AD
 	} else {
 		i = lp->isa_config & INT_NO_MASK;
 		if (lp->chip_type == CS8900) {
-#ifdef CONFIG_ARCH_IXDP2X01
+#if defined (CONFIG_ARCH_IXDP2X01) || defined(CONFIG_ARCH_PNX0105)
 		        i = cs8900_irq_map[0];
 #else
 			/* Translate the IRQ using the IRQ mapping table. */
@@ -1145,7 +1175,7 @@ net_open(struct net_device *dev)
 	int i;
 	int ret;
 
-#ifndef CONFIG_SH_HICOSH4 /* uses irq#1, so this won't work */
+#if !defined(CONFIG_SH_HICOSH4) && !defined(CONFIG_ARCH_PNX0105) /* uses irq#1, so this won't work */
 	if (dev->irq < 2) {
 		/* Allow interrupts to be generated by the chip */
 /* Cirrus' release had this: */
@@ -1176,7 +1206,7 @@ net_open(struct net_device *dev)
 	else
 #endif
 	{
-#ifndef CONFIG_ARCH_IXDP2X01
+#if !defined(CONFIG_ARCH_IXDP2X01) && !defined(CONFIG_ARCH_PNX0105)
 		if (((1 << dev->irq) & lp->irq_map) == 0) {
 			printk(KERN_ERR "%s: IRQ %d is not in our map of allowable IRQs, which is %x\n",
                                dev->name, dev->irq, lp->irq_map);
@@ -1261,6 +1291,9 @@ net_open(struct net_device *dev)
 	case A_CNF_MEDIA_10B_2: result = lp->adapter_cnf & A_CNF_10B_2; break;
         default: result = lp->adapter_cnf & (A_CNF_10B_T | A_CNF_AUI | A_CNF_10B_2);
         }
+#ifdef CONFIG_ARCH_PNX0105
+	result = A_CNF_10B_T;
+#endif
         if (!result) {
                 printk(KERN_ERR "%s: EEPROM is configured for unavailable media\n", dev->name);
         release_irq:
diff -puN drivers/net/cs89x0.h~cs89x0c-support-for-philips-pnx0105-network-adapter drivers/net/cs89x0.h
--- 25/drivers/net/cs89x0.h~cs89x0c-support-for-philips-pnx0105-network-adapter	2005-05-23 19:41:00.000000000 -0700
+++ 25-akpm/drivers/net/cs89x0.h	2005-05-23 19:41:00.000000000 -0700
@@ -16,7 +16,7 @@
 
 #include <linux/config.h>
 
-#ifdef CONFIG_ARCH_IXDP2X01
+#if defined(CONFIG_ARCH_IXDP2X01) || defined(CONFIG_ARCH_PNX0105)
 /* IXDP2401/IXDP2801 uses dword-aligned register addressing */
 #define CS89x0_PORT(reg) ((reg) * 2)
 #else
diff -puN drivers/net/Kconfig~cs89x0c-support-for-philips-pnx0105-network-adapter drivers/net/Kconfig
--- 25/drivers/net/Kconfig~cs89x0c-support-for-philips-pnx0105-network-adapter	2005-05-23 19:41:00.000000000 -0700
+++ 25-akpm/drivers/net/Kconfig	2005-05-23 19:41:00.000000000 -0700
@@ -1320,7 +1320,7 @@ config FORCEDETH
 
 config CS89x0
 	tristate "CS89x0 support"
-	depends on NET_PCI && (ISA || ARCH_IXDP2X01)
+	depends on (NET_PCI && (ISA || ARCH_IXDP2X01)) || ARCH_PNX0105
 	---help---
 	  Support for CS89x0 chipset based Ethernet cards. If you have a
 	  network (Ethernet) card of this type, say Y and read the
_
